==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/en-ID/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Pengguna ini dapat masuk',
    'activated_disabled_help_text' => 'Anda tidak dapat menyunting status aktivasi akun anda sendiri.',
    'assets_user'       => 'Aset ditetapkan untuk :name',
    'bulk_update_warn'	=> 'Anda akan sunting properti dari :user_count pengguna. Silahkan catat anda tidak dapat menggubah atribut pengguna anda sendiri menggunakan formulir ini, dan harus membuat penyuntingan untuk pengguna anda sendiri secara pribadi.',
    'bulk_update_help'	=> 'Formulir ini membolehkan anda perbarui beberapa pengguna sekaligus. Hanya mengisi bidang yang anda perlu ubah. Setiap bidang yang kosong akan tetap tidak berubah.',
    'current_assets'    => 'Aset saat ini diperiksa untuk pengguna ini',
    'clone'             => 'Gandakan pengguna',
    'contact_user'      => 'Kontak :name',
    'edit'              => 'Sunting Pengguna',
    'filetype_info'     => 'Tipe file yang dibolehkan png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Riwayat untuk :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klik disini untuk mengembalikan mereka.',
    'last_login'        => 'Masuk terakhir',
    'ldap_config_text'  => 'Pengaturan konfigurasi LDAP dapat ditemukan di Admin > Pengaturan. Lokasi pilihan (opsional) akan di atur untuk semua pengguna yang diimpor.',
    'print_assigned'    => 'Cetak semua yang ditetapkan',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Software diperiksa untuk :name',
    'send_email_help'   => 'Anda harus menyediakan sebuah alamat email untuk pengguna ini untuk dikirimkan kredesial pada mereka. Kredensial penyuratan/email hanya dapat dilakukan pada pembuatan pengguna. Kata sandi disimpan dalam sebuah hash satu-arah dan tidak dapat diterima lagi setelah disimpan.',
    'view_user'         => 'Lihat pengguna :name',
    'usercsv'           => 'Berkas CSV',
    'two_factor_admin_optin_help' => 'Pengaturan admin anda saat ini membolehkan pelaksanaan otentifikasi dua-faktor secara selektif.  ',
    'two_factor_enrolled' => 'Perangkat 2FA Terdaftar ',
    'two_factor_active'   => '2FA Aktif ',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/en-ID/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Pengguna ini dapat masuk',
    'activated_disabled_help_text' => 'Anda tidak dapat menyunting status aktivasi akun anda sendiri.',
    'assets_user'       => 'Aset ditetapkan untuk :name',
    'bulk_update_warn'	=> 'Anda akan sunting properti dari :user_count pengguna. Silahkan catat anda tidak dapat menggubah atribut pengguna anda sendiri menggunakan formulir ini, dan harus membuat penyuntingan untuk pengguna anda sendiri secara pribadi.',
    'bulk_update_help'	=> 'Formulir ini membolehkan anda perbarui beberapa pengguna sekaligus. Hanya mengisi bidang yang anda perlu ubah. Setiap bidang yang kosong akan tetap tidak berubah.',
    'current_assets'    => 'Aset saat ini diperiksa untuk pengguna ini',
    'clone'             => 'Gandakan pengguna',
    'contact_user'      => 'Kontak :name',
    'edit'              => 'Sunting Pengguna',
    'filetype_info'     => 'Tipe file yang dibolehkan png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Riwayat untuk :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klik disini untuk mengembalikan mereka.',
    'last_login'        => 'Masuk terakhir',
    'ldap_config_text'  => 'Pengaturan konfigurasi LDAP dapat ditemukan di Admin > Pengaturan. Lokasi pilihan (opsional) akan di atur untuk semua pengguna yang diimpor.',
    'print_assigned'    => 'Cetak semua yang ditetapkan',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Software diperiksa untuk :name',
    'send_email_help'   => 'Anda harus menyediakan sebuah alamat email untuk pengguna ini untuk dikirimkan kredesial pada mereka. Kredensial penyuratan/email hanya dapat dilakukan pada pembuatan pengguna. Kata sandi disimpan dalam sebuah hash satu-arah dan tidak dapat diterima lagi setelah disimpan.',
    'view_user'         => 'Lihat pengguna :name',
    'usercsv'           => 'Berkas CSV',
    'two_factor_admin_optin_help' => 'Pengaturan admin anda saat ini membolehkan pelaksanaan otentifikasi dua-faktor secara selektif.  ',
    'two_factor_enrolled' => 'Perangkat 2FA Terdaftar ',
    'two_factor_active'   => '2FA Aktif ',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
